@@ -11,7 +11,7 @@ use strict;
 use warnings;
 use base 'Mojolicious::Plugin';
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Mojo::UserAgent;
 use URI::Escape qw(uri_escape);
@@ -151,7 +151,7 @@ successful. Don't forget to expire it!
     get '/' => sub {
         my $self = shift;
 
-        return $self->render_text("yubikey id is @{[$self->session->{'yubi'}]}")
+        return $self->render(text => "yubikey id is @{[$self->session->{'yubi'}]}")
           if $self->basic_auth(
                   realm => sub { return 1 if $self->session->{'yubi'};
                                  return 1 if $self->session->{'yubi'} =
